@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -26,7 +26,8 @@ static HMODULE libbabl_dll = NULL;
 
 /* Minimal DllMain that just stores the handle to this DLL */
 
-BOOL WINAPI			/* Avoid silly "no previous prototype" gcc warning */
+/* Avoid silly "no previous prototype" gcc warning */
+BOOL WINAPI
 DllMain (HINSTANCE hinstDLL,
          DWORD     fdwReason,
          LPVOID    lpvReserved);
@@ -136,6 +137,8 @@ babl_init (void)
       babl_internal_init ();
       babl_sampling_class_init ();
       babl_type_db ();
+      babl_trc_class_init ();
+      babl_space_class_init ();
       babl_component_db ();
       babl_model_db ();
       babl_format_db ();
@@ -150,6 +153,8 @@ babl_init (void)
       dir_list = babl_dir_list ();
       babl_extension_load_dir_list (dir_list);
       babl_free (dir_list);
+
+      babl_init_db ();
     }
 }
 
@@ -158,17 +163,7 @@ babl_exit (void)
 {
   if (!-- ref_count)
     {
-      if (getenv ("BABL_STATS"))
-        {
-          char  logfile_name[] = "/tmp/babl-stats.html";
-          FILE *logfile;
-          logfile = fopen (logfile_name, "w");
-          if (logfile)
-            {
-              babl_fish_stats (logfile);
-              fclose (logfile);
-            }
-        }
+      babl_store_db ();
 
       babl_extension_deinit ();
       babl_free (babl_extension_db ());;
@@ -185,3 +180,13 @@ babl_exit (void)
 #endif
     }
 }
+
+#undef babl_model_is
+
+int 
+babl_model_is (const Babl *babl,
+               const char *model)
+{
+  return babl && ((babl)==babl_model_with_space(model, babl));
+}
+
